diff graal/GraalCompiler/src/com/sun/c1x/ir/LoadField.java @ 2622:91d3952f7eb7

Framestate work : using stateAFter and reducting the number of nodes with framestates. Intermediate state (does not pass tests)
author Gilles Duboscq <gilles.duboscq@oracle.com>
date Tue, 10 May 2011 12:37:46 +0200
parents 4a4dab936c1e
children 569228710be8
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/LoadField.java	Tue May 10 11:55:12 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/LoadField.java	Tue May 10 12:37:46 2011 +0200
@@ -41,12 +41,12 @@
      * @param object the receiver object
      * @param field the compiler interface field
      * @param isStatic indicates if the field is static
      * @param stateBefore the state before the field access
      * @param graph
      * @param isLoaded indicates if the class is loaded
      */
-    public LoadField(Value object, RiField field, FrameState stateBefore, Graph graph) {
-        super(field.kind().stackKind(), object, field, stateBefore, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public LoadField(Value object, RiField field, FrameState stateAfter, Graph graph) {
+        super(field.kind().stackKind(), object, field, stateAfter, INPUT_COUNT, SUCCESSOR_COUNT, graph);
     }
 
     /**
@@ -41,12 +41,12 @@
      * @param field the compiler interface field
      * @param isStatic indicates if the field is static
-     * @param stateBefore the state before the field access
+     * @param stateAfter the state after the field access
      * @param graph
      * @param isLoaded indicates if the class is loaded